%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not modify this file since it was automatically generated from:
% 
%  001.R.KEYWORDS.R
% 
% by the Rdoc compiler part of the R.oo package.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\name{R.KEYWORDS}
\alias{R.KEYWORDS}

\title{Reserved words in R not to be used for object names}

\description{
 Reserved words in R not to be used for object names. \code{R.KEYWORDS} is a \code{\link[base]{character}} \code{\link[base]{vector}} of all reserved
 words in \R according to [1].
}

\author{Henrik Bengtsson}

\references{
 [1] Section "Reserved words", R Language Definition, version 2.6.0
     (2007-09-14) DRAFT.
}



\keyword{programming}
\keyword{internal}
